pub struct GenericElement { /* private fields */ }Expand description
GenericElement is a struct that represents a single element in a generic template.
Each GenericElement can contain a title, subtitle, image, and multiple buttons.
Fields
title: A string that represents the title of the element.image_url: A string that represents the URL of the image to be displayed in the element.subtitle: A string that represents the subtitle of the element.buttons: A vector ofButtonstructs that represent the buttons to be displayed in the element.
Examples
Creating a GenericElement:
// use russenger::response_models::data::Data;
// use russenger::response_models::button::Button;
// use russenger::response_models::payload::Payload;
// use russenger::response_models::generic::GenericElement;
use russenger::prelude::*; // if you use this import other imports are not needed;
let element = GenericElement::new(
"Title",
"https://example.com/image.jpg",
"Subtitle",
vec![Button::Postback {
title: "Hello World",
payload: Payload::new("/hello_world", Some(Data::new("Hello World!"))),
}],
);
async fn hello_world(res: Res, req: Req) -> Result<()> {
let hello_world: String = req.data.get_value()?;
res.send(TextModel::new(&req.user, &hello_world)).await?;
Ok(())
}Implementations
Sourceimpl GenericElement
impl GenericElement
Sourcepub fn new(
title: impl ToString,
image_url: impl ToString,
subtitle: impl ToString,
buttons: impl IntoIterator<Item = Button<impl ToString>>,
) -> Self
pub fn new( title: impl ToString, image_url: impl ToString, subtitle: impl ToString, buttons: impl IntoIterator<Item = Button<impl ToString>>, ) -> Self
new is a method of the GenericElement struct that creates a new instance of GenericElement.
Parameters
title: &str- The title of the element.image_url: &str- The URL of the image to be displayed in the element.subtitle: &str- The subtitle of the element.buttons: Vec<Button>- A vector ofButtonstructs that represent the buttons to be displayed in the element.
Panics
This method will panic if the number of buttons is more than 3, as Facebook Messenger only allows a maximum of 3 buttons per element.
Returns
A new GenericElement instance.
Examples
Creating a new GenericElement:
use russenger::prelude::*; // if you use this import other imports are not needed;
let element = GenericElement::new(
"Title",
"https://example.com/image.jpg",
"Subtitle",
vec![Button::Postback {
title: "Hello World",
payload: Payload::new("/hello_world", Some(Data::new("Hello World!"))),
}],
);
async fn hello_world(res: Res, req: Req) -> Result<()> {
let hello_world: String = req.data.get_value()?;
res.send(TextModel::new(&req.user, &hello_world)).await?;
Ok(())
}This example shows how to create a new GenericElement.